#ifndef NT2_INCLUDE_FUNCTIONS_COSH_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_COSH_HPP_INCLUDED

#include <nt2/hyperbolic/include/functions/cosh.hpp>

#endif
